![enigme](./images/logo.png "enigme")

*Text based Puzzle Generators for AI Research*

This repository contains functions for generating puzzles
composed of blocks of English text or ASCII based diagrams.

There is a command line application for interacting with the puzzle generators
as well as a library that can be used to incorporate these puzzles in your
application of model testing framework.

The puzzles are generated randomly from predetermined distributions. Each
of the generators is designed to use text to create higher level representations
of a puzzle domain that requires the development of spontaneous mental models
in order to manipulate cognitively to reason about and solve the problems.

Some CLI parameters allow for generating from restricted complexty sets. These
are used when experimenting with complexity thresholds that affect both human
and machine performance on these tasks.

## Usage


## Citations
 
This package is being presented at the [ICEAST conference in May 2025](https://iceast.kmitl.ac.th/2025/)

```bibtex
@article{hawkins:2025,
  author = {John Hawkins},
  title = {Enigme: Generative Text Puzzles for Evaluating Reasoning in Language Models}
  booktitle = {2025 11th International Conference on Engineering, Applied Sciences, and Technology (ICEAST)}
  year = {2025},
  month = {05},
}
```

Additional work on analysis to follow, watch this space.


